@@ -2,11 +2,12 @@ package DhMakePerl;
 
 use warnings;
 use strict;
+use 5.010;    # we use smart matching
 
 use base 'Class::Accessor';
 use Pod::Usage;
 
-__PACKAGE__->mk_accessors( qw( cfg apt_contents main_dir meta ) );
+__PACKAGE__->mk_accessors(qw( cfg apt_contents main_dir meta ));
 
 =head1 NAME
 
@@ -14,11 +15,11 @@ DhMakePerl - create Debian source package from CPAN dist
 
 =head1 VERSION
 
-Version 0.60
+Version 0.62
 
 =cut
 
-our $VERSION = '0.60';
+our $VERSION = '0.62';
 
 =head1 SYNOPSIS
 
@@ -36,14 +37,15 @@ TO BE FILLED
 =cut
 
 use AptPkg::Cache ();
+use Array::Unique;
 use Config qw( %Config );
 use CPAN ();
 use Cwd qw( getcwd );
-use Debian::AptContents ();
-use Debian::Control ();
+use Debian::AptContents       ();
+use Debian::Control           ();
 use Debian::Control::FromCPAN ();
-use Debian::Dependencies ();
-use Debian::Dependency ();
+use Debian::Dependencies      ();
+use Debian::Dependency        ();
 use Debian::Version qw(deb_ver_cmp);
 use Parse::DebianChangelog;
 use DhMakePerl::Config;
@@ -53,25 +55,24 @@ use File::Basename qw( basename dirname );
 use File::Copy qw( copy move );
 use File::Find qw( find );
 use File::Spec::Functions qw( catfile );
-use IO::File ();
-use Module::CoreList ();
+use IO::File                   ();
+use Module::CoreList           ();
 use Module::Depends::Intrusive ();
-use Module::Depends ();
+use Module::Depends            ();
 use Text::Wrap qw( fill wrap );
 use Tie::File;
 use User::pwent qw(:FIELDS);
 use WWW::Mechanize ();
-use YAML ();
+use YAML           ();
 use version qw( qv );
 
-
 # TODO:
 # * get more info from the package (maybe using CPAN methods)
 
-my ($oldest_perl_version,
-    $debstdversion, $priority,  $section,
-    $depends,          $bdepends,      $bdependsi, $maintainer,
-    $arch,             $closes,        $date,      $debiandir,
+my ($oldest_perl_version, $debstdversion, $priority,
+    $section,             $depends,       $bdepends,
+    $bdependsi,           $maintainer,    $arch,
+    $closes,              $date,          $debiandir,
     $startdir,
 );
 our %overrides;
@@ -108,6 +109,10 @@ my ( $extrasfields, $extrapfields );
 my ($module_build);
 my ( @docs, @examples, $changelog, @args );
 
+# use Array::Unique for @docs and @examples
+tie @examples, 'Array::Unique';
+tie @docs,     'Array::Unique';
+
 my $mod_cpan_version;
 
 =item main_file(file_name)
@@ -191,14 +196,15 @@ sub run {
         print "Engaging refresh mode\n" if $self->cfg->verbose;
         $self->main_dir('.');
 
-        die $self->debian_file('rules.bak')." already exists. Aborting!\n"
-            if -e $self->debian_file('rules.bak');
+        die $self->debian_file('rules.bak') . " already exists. Aborting!\n"
+            if ( -e $self->debian_file('rules.bak') and 'rules' ~~ $self->cfg->only );
 
-        die $self->debian_file('copyright.bak')." already exists. Aborting!\n"
-            if -e $self->debian_file('copyright.bak');
+        die $self->debian_file('copyright.bak')
+            . " already exists. Aborting!\n"
+            if ( -e $self->debian_file('copyright.bak') and 'copyright' ~~ $self->cfg->only );
 
-        die $self->debian_file('control.bak')." already exists. Aborting!\n"
-            if -e $self->debian_file('control.bak');
+        die $self->debian_file('control.bak') . " already exists. Aborting!\n"
+            if ( -e $self->debian_file('control.bak') and 'control' ~~ $self->cfg->only );
 
         $self->process_meta;
         ( $pkgname, $version )
@@ -207,47 +213,58 @@ sub run {
             = ( -f $self->main_file('Build.PL') ) ? "Module-Build" : "MakeMaker";
 
         $self->extract_changelog;
-        $self->extract_docs;
-        $self->extract_examples;
+        $self->extract_docs if 'docs' ~~ $self->cfg->only;
+        $self->extract_examples if 'examples' ~~ $self->cfg->only;
         print "Found changelog: $changelog\n"
             if defined $changelog and $self->cfg->verbose;
-        print "Found docs: @docs\n" if $self->cfg->verbose;
+        print "Found docs: @docs\n" if @docs and $self->cfg->verbose;
         print "Found examples: @examples\n" if @examples and $self->cfg->verbose;
-        $self->backup_file( $self->debian_file('rules') );
-        $self->create_rules( $self->debian_file('rules') );
-        if (! -f $self->debian_file('compat') or $self->cfg->dh == 7) {
-            $self->create_compat( $self->debian_file('compat') );
+
+        if ( 'rules' ~~ $self->cfg->only ) {
+            $self->backup_file( $self->debian_file('rules') );
+            $self->create_rules( $self->debian_file('rules') );
+            if (! -f $self->debian_file('compat') or $self->cfg->dh == 7) {
+                $self->create_compat( $self->debian_file('compat') );
+            }
         }
+
+        if ( 'docs' ~~ $self->cfg->only or 'examples' ~~ $self->cfg->only) {
         $self->fix_rules( $self->debian_file('rules'),
             ( defined $changelog ? $changelog : '' ),
             \@docs, \@examples, );
-        $self->backup_file( $self->debian_file('copyright') );
-        $self->create_copyright("$debiandir/copyright");
-
-        my $control = Debian::Control::FromCPAN->new;
-        $control->read( $self->debian_file('control') );
-        if ( -e catfile( $self->debian_file('patches'), 'series' ) ) {
-            $self->add_quilt( $control );
-        }
-        else {
-            $self->drop_quilt( $control );
         }
 
-        if( my $apt_contents = $self->get_apt_contents ) {
-            $control->dependencies_from_cpan_meta(
-                $self->meta, $self->get_apt_contents, $self->cfg->verbose );
-        }
-        else {
-            warn "No APT contents can be loaded.\n";
-            warn "Please install 'apt-file' package and run 'apt-file update'\n";
-            warn "as root.\n";
-            warn "Dependencies not updated.\n";
+        if ( 'copyright' ~~ $self->cfg->only ) {
+            $self->backup_file( $self->debian_file('copyright') );
+            $self->create_copyright("$debiandir/copyright");
         }
 
-        $control->prune_perl_deps();
+        if ( 'control' ~~ $self->cfg->only ) {
+            my $control = Debian::Control::FromCPAN->new;
+            $control->read( $self->debian_file('control') );
+            if ( -e catfile( $self->debian_file('patches'), 'series' ) ) {
+                $self->add_quilt( $control );
+            }
+            else {
+                $self->drop_quilt( $control );
+            }
 
-        $self->backup_file( $self->debian_file('control') );
-        $control->write( $self->debian_file('control') );
+            if( my $apt_contents = $self->get_apt_contents ) {
+                $control->dependencies_from_cpan_meta(
+                    $self->meta, $self->get_apt_contents, $self->cfg->verbose );
+            }
+            else {
+                warn "No APT contents can be loaded.\n";
+                warn "Please install 'apt-file' package and run 'apt-file update'\n";
+                warn "as root.\n";
+                warn "Dependencies not updated.\n";
+            }
+
+            $control->prune_perl_deps();
+
+            $self->backup_file( $self->debian_file('control') );
+            $control->write( $self->debian_file('control') );
+        }
 
         print "--- Done\n" if $self->cfg->verbose;
         return 0;
@@ -272,7 +289,7 @@ EOF
         my $mod = $ARGV[0];
 
         if ( defined( my $core_since = $self->is_core_module($mod) ) ) {
-            print "$mod is in Perl core (package perl-modules)";
+            print "$mod is in Perl core (package perl)";
             print $core_since ? " since $core_since\n" : "\n";
             return 0;
         }
@@ -399,10 +416,10 @@ sub get_apt_contents {
         if $self->apt_contents;
 
     my $apt_c = Debian::AptContents->new(
-        {   homedir      => $self->cfg->home_dir,
-            dist         => $self->cfg->dist,
-            sources_file => $self->cfg->sources_list,
-            verbose      => $self->cfg->verbose,
+        {   homedir => $self->cfg->home_dir,
+            dist    => $self->cfg->dist,
+            sources => $self->cfg->sources_list,
+            verbose => $self->cfg->verbose,
         }
     );
 
@@ -441,11 +458,11 @@ sub configure_cpan {
     unshift( @{ $CPAN::Config->{'urllist'} }, $self->cfg->cpan_mirror )
         if $self->cfg->cpan_mirror;
 
-    $CPAN::Config->{'build_dir'} = $ENV{'HOME'} . "/.cpan/build";
-    $CPAN::Config->{'cpan_home'} = $ENV{'HOME'} . "/.cpan/";
-    $CPAN::Config->{'histfile'}  = $ENV{'HOME'} . "/.cpan/history";
+    $CPAN::Config->{'build_dir'}         = $ENV{'HOME'} . "/.cpan/build";
+    $CPAN::Config->{'cpan_home'}         = $ENV{'HOME'} . "/.cpan/";
+    $CPAN::Config->{'histfile'}          = $ENV{'HOME'} . "/.cpan/history";
     $CPAN::Config->{'keep_source_where'} = $ENV{'HOME'} . "/.cpan/source";
-    $CPAN::Config->{'tar_verbosity'} = $self->cfg->verbose ? 'v' : '';
+    $CPAN::Config->{'tar_verbosity'}     = $self->cfg->verbose ? 'v' : '';
     $CPAN::Config->{'load_module_verbosity'}
         = $self->cfg->verbose ? 'verbose' : 'silent';
 }
@@ -490,7 +507,11 @@ sub setup_dir {
     my ( $dist, $mod, $tarball );
     $mod_cpan_version = '';
     if ( $self->cfg->cpan ) {
-        my ($new_maindir);
+        my ($new_maindir, $orig_pwd);
+
+        # CPAN::Distribution::get() sets $ENV{'PWD'} to $CPAN::Config->{build_dir}
+        # so we have to save it here
+        $orig_pwd = $ENV{'PWD'};
 
         # Is the module a core module?
         if ( $self->is_core_module( $self->cfg->cpan ) ) {
@@ -509,16 +530,16 @@ sub setup_dir {
 
         $dist = $CPAN::META->instance( 'CPAN::Distribution',
             $mod->cpan_file );
-        $dist->get || die "Cannot get ", $mod->cpan_file, "\n";
+        $dist->get || die "Cannot get ", $mod->cpan_file, "\n"; # <- here $ENV{'PWD'} gets set to $HOME/.cpan/build
         $tarball .= $mod->cpan_file;
         $self->main_dir( $dist->dir );
 
-        copy( $tarball, $ENV{'PWD'} );
-        $tarball = $ENV{'PWD'} . "/" . basename($tarball);
+        copy( $tarball, $orig_pwd );
+        $tarball = $orig_pwd . "/" . basename($tarball);
 
         # build_dir contains a random part since 1.88_59
         # use the new CPAN::Distribution::base_id (introduced in 1.91_53)
-        $new_maindir = $ENV{PWD} . "/" . $dist->base_id;
+        $new_maindir = $orig_pwd . "/" . $dist->base_id;
 
         # rename existing directory
         if ( -d $new_maindir
@@ -969,9 +990,18 @@ sub extract_docs {
     $dir .= '/' unless $dir =~ m(/$);
     find(
         sub {
+            if (   $File::Find::dir eq '.svn-base'
+                or $File::Find::dir eq '.git' )
+            {
+                $File::Find::prune = 1;
+                return;
+            }
             push( @docs, substr( $File::Find::name, length($dir) ) )
-                if ( /^(README|TODO|BUGS|NEWS|ANNOUNCE)/i
-                and ( !$self->cfg->exclude or $File::Find::name !~ $self->cfg->exclude )
+                if (
+                    /^\b(README|TODO|BUGS|NEWS|ANNOUNCE)\b/i
+                and !/\.(pod|pm)$/
+                and ( !$self->cfg->exclude
+                    or $File::Find::name !~ $self->cfg->exclude )
                 and !/\.svn-base$/
                 );
         },
@@ -987,7 +1017,7 @@ sub extract_examples {
     $dir .= '/' unless $dir =~ m{/$};
     find(
         sub {
-            return unless length($_) > length($dir);  # skip the directory itself
+            return if $_ eq '.';  # skip the directory itself
             my $exampleguess = substr( $File::Find::name, length($dir) );
             push( @examples,
                 ( -d $exampleguess ? $exampleguess . '/*' : $exampleguess ) )
@@ -1083,8 +1113,8 @@ sub find_debs_for_modules {
         ) {
             print "= $module is a core module\n" if $self->cfg->verbose;
 
-            $dep = Debian::Dependency->new( 'perl-modules', $ver );
-            $debs->add($dep) if $dep->satisfies( "perl-modules (>= $oldest_perl_version)" );
+            $dep = Debian::Dependency->new( 'perl', $ver );
+            $debs->add($dep) if $dep->satisfies( "perl (>= $oldest_perl_version)" );
 
             next;
         }
@@ -1445,12 +1475,40 @@ sub fix_rules {
     else {
         $fh->print($_) for @content;
         if (@examples) {
-            open F, '>>', $self->debian_file("$pkgname.examples") or die $!;
+            # pkgname.examples file
+            my $pkg_examples_file = $self->debian_file("$pkgname.examples");
+
+            # if a package.examples exists read these values first
+            if ( -r $pkg_examples_file ) {
+                my $fh                = $self->_file_r($pkg_examples_file);
+                my @existing_examples = $fh->getlines;
+                chomp(@existing_examples);
+
+                # make list of files for package.examples unique
+                push @examples, @existing_examples;
+            }
+
+            # write package.examples file with unique entries
+            open F, '>', $pkg_examples_file or die $!;
             print F "$_\n" foreach @examples;
             close F;
         }
         if (@docs) {
-            open F, '>>', $self->debian_file("$pkgname.docs") or die $!;
+            # pkgname.docs file
+            my $pkg_docs_file = $self->debian_file("$pkgname.docs");
+
+            # if a apcakge.docs exists read these values first
+            if ( -r $pkg_docs_file ) {
+                my $fh            = $self->_file_r($pkg_docs_file);
+                my @existing_docs = $fh->getlines;
+                chomp(@existing_docs);
+
+                # make list of files for package.docs unique
+                push @docs, @existing_docs;
+            }
+
+            # write package.docs with unique entries
+            open F, '>', $pkg_docs_file or die $!;
             print F "$_\n" foreach @docs;
             close F;
         }
@@ -1600,8 +1658,7 @@ sub create_copyright {
     $cprt_author =~ s/\n/\n    /gs;
     $cprt_author =~ s/^\s*$/    ./gm;
 
-    push @res, "Format-Specification:
-    http://wiki.debian.org/Proposals/CopyrightFormat?action=recall&rev=196";
+    push @res, "Format-Specification: http://svn.debian.org/wsvn/dep/web/deps/dep5.mdwn?op=file&rev=135";
 
     # Header section
     %fields = (
@@ -1610,7 +1667,7 @@ sub create_copyright {
         Source     => $upsurl
     );
     for my $key ( keys %fields ) {
-        my $full = "Upstream-$key";
+        my $full = "$key";
         if ( $fields{$key} ) {
             push @res, "$full: $fields{$key}";
         }
@@ -1619,12 +1676,14 @@ sub create_copyright {
         }
     }
     push( @res,
-        "Disclaimer: This copyright info was automatically extracted ",
-        "    from the perl module. It may not be accurate, so you better ",
-        "    check the module sources in order to ensure the module for its ",
-        "    inclusion in Debian or for general legal information. Please, ",
-        "    if licensing information is incorrectly generated, file a bug ",
-        "    on dh-make-perl." );
+        "DISCLAIMER: This copyright info was automatically extracted ",
+        " from the perl module. It may not be accurate, so you better ",
+        " check the module sources in order to ensure the module for its ",
+        " inclusion in Debian or for general legal information. Please, ",
+        " if licensing information is incorrectly generated, file a bug ",
+        " on dh-make-perl.",
+        " NOTE: Don't forget to remove this disclaimer once you are happy",
+        " with this file." );
     push @res, '';
 
     # Files section - We cannot "parse" the module's licensing
@@ -1643,60 +1702,67 @@ sub create_copyright {
     my ( %texts, %licenses );
     %texts = (
         'Artistic' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the Artistic License, which comes with Perl.\n"
-            . "    On Debian GNU/Linux systems, the complete text of the Artistic License\n"
-            . "    can be found in `/usr/share/common-licenses/Artistic'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the Artistic License, which comes with Perl.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of the Artistic License\n"
+            . " can be found in `/usr/share/common-licenses/Artistic'",
         'GPL-1+' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the GNU General Public License as published by\n"
-            . "    the Free Software Foundation; either version 1, or (at your option)\n"
-            . "    any later version.\n"
-            . "    On Debian GNU/Linux systems, the complete text of the GNU General\n"
-            . "    Public License can be found in `/usr/share/common-licenses/GPL'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the GNU General Public License as published by\n"
+            . " the Free Software Foundation; either version 1, or (at your option)\n"
+            . " any later version.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of the GNU General\n"
+            . " Public License can be found in `/usr/share/common-licenses/GPL'",
         'GPL-2' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the GNU General Public License as published by\n"
-            . "    the Free Software Foundation; version 2 dated June, 1991.\n"
-            . "    On Debian GNU/Linux systems, the complete text of version 2 of the GNU\n"
-            . "    General Public License can be found in `/usr/share/common-licenses/GPL-2'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the GNU General Public License as published by\n"
+            . " the Free Software Foundation; version 2 dated June, 1991.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of version 2 of the GNU\n"
+            . " General Public License can be found in `/usr/share/common-licenses/GPL-2'",
         'GPL-2+' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the GNU General Public License as published by\n"
-            . "    the Free Software Foundation; version 2 dated June, 1991, or (at your\n"
-            . "    option) any later version.\n"
-            . "    On Debian GNU/Linux systems, the complete text of version 2 of the GNU\n"
-            . "    General Public License can be found in `/usr/share/common-licenses/GPL-2'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the GNU General Public License as published by\n"
+            . " the Free Software Foundation; version 2 dated June, 1991, or (at your\n"
+            . " option) any later version.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of version 2 of the GNU\n"
+            . " General Public License can be found in `/usr/share/common-licenses/GPL-2'",
         'GPL-3' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the GNU General Public License as published by\n"
-            . "    the Free Software Foundation; version 3 dated June, 2007.\n"
-            . "    On Debian GNU/Linux systems, the complete text of version 3 of the GNU\n"
-            . "    General Public License can be found in `/usr/share/common-licenses/GPL-3'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the GNU General Public License as published by\n"
+            . " the Free Software Foundation; version 3 dated June, 2007.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of version 3 of the GNU\n"
+            . " General Public License can be found in `/usr/share/common-licenses/GPL-3'",
         'GPL-3+' =>
-            "    This program is free software; you can redistribute it and/or modify\n"
-            . "    it under the terms of the GNU General Public License as published by\n"
-            . "    the Free Software Foundation; version 3 dated June, 2007, or (at your\n"
-            . "    option) any later version\n"
-            . "    On Debian GNU/Linux systems, the complete text of version 3 of the GNU\n"
-            . "    General Public License can be found in `/usr/share/common-licenses/GPL-3'",
+            " This program is free software; you can redistribute it and/or modify\n"
+            . " it under the terms of the GNU General Public License as published by\n"
+            . " the Free Software Foundation; version 3 dated June, 2007, or (at your\n"
+            . " option) any later version\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of version 3 of the GNU\n"
+            . " General Public License can be found in `/usr/share/common-licenses/GPL-3'",
         'Apache-2.0' =>
-            "    Licensed under the Apache License, Version 2.0 (the \"License\");\n"
-            . "    you may not use this file except in compliance with the License.\n"
-            . "    You may obtain a copy of the License at\n"
-            . "        http://www.apache.org/licenses/LICENSE-2.0\n"
-            . "    Unless required by applicable law or agreed to in writing, software\n"
-            . "    distributed under the License is distributed on an \"AS IS\" BASIS,\n"
-            . "    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"
-            . "    See the License for the specific language governing permissions and\n"
-            . "    limitations under the License.\n"
-            . "    On Debian GNU/Linux systems, the complete text of the Apache License,\n"
-            . "    Version 2.0 can be found in `/usr/share/common-licenses/Apache-2.0'",
+            " Licensed under the Apache License, Version 2.0 (the \"License\");\n"
+            . " you may not use this file except in compliance with the License.\n"
+            . " You may obtain a copy of the License at\n"
+            . "     http://www.apache.org/licenses/LICENSE-2.0\n"
+            . " Unless required by applicable law or agreed to in writing, software\n"
+            . " distributed under the License is distributed on an \"AS IS\" BASIS,\n"
+            . " WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"
+            . " See the License for the specific language governing permissions and\n"
+            . " limitations under the License.\n"
+            . " .\n"
+            . " On Debian GNU/Linux systems, the complete text of the Apache License,\n"
+            . " Version 2.0 can be found in `/usr/share/common-licenses/Apache-2.0'",
         'unparsable' =>
-            "    No known license could be automatically determined for this module.\n"
-            . "    If this module conforms to a commonly used license, please report this\n"
-            . "    as a bug in dh-make-perl. In any case, please find the proper license\n"
-            . "    and fix this file!"
+            " No known license could be automatically determined for this module.\n"
+            . " If this module conforms to a commonly used license, please report this\n"
+            . " as a bug in dh-make-perl. In any case, please find the proper license\n"
+            . " and fix this file!"
     );
 
     if ( $self->meta->{license} or $copyright ) {
@@ -1714,7 +1780,6 @@ sub create_copyright {
         if (   $self->meta->{license} and $self->meta->{license} =~ /perl/i
             or $mangle_cprt =~ /terms\s*as\s*Perl\s*itself/is )
         {
-            push @res, "License-Alias: Perl";
             $licenses{'GPL-1+'}   = 1;
             $licenses{'Artistic'} = 1;
         }
@@ -1759,7 +1824,7 @@ sub create_copyright {
             }
         }
 
-        push @res, "License: " . join( ' | ', keys %licenses );
+        push @res, "License: " . join( ' or ', keys %licenses );
 
     }
     else {
@@ -1779,7 +1844,7 @@ sub create_copyright {
     } else {
       push @res, "Copyright: $year, $maintainer";
     }
-    push @res, "License: " . join( ' | ', keys %licenses );
+    push @res, "License: " . join( ' or ', keys %licenses );
 
     map { $texts{$_} && push( @res, '', "License: $_", $texts{$_} ) }
         keys %licenses;
@@ -2107,19 +2172,23 @@ L<http://bugs.debian.org/dh-make-perl>
 
 =over 4
 
-=item Copyright (C) 2000,2001 Paolo Molaro <lupus@debian.org>
+=item Copyright (C) 2000, 2001 Paolo Molaro <lupus@debian.org>
 
-=item Copyright (C) 2002,2003,2008 Ivan Kohler <ivan-debian@420.am>
+=item Copyright (C) 2002, 2003, 2008 Ivan Kohler <ivan-debian@420.am>
 
-=item Copyright (C) 2003,2004 Marc 'HE' Brockschmidt <he@debian.org>
+=item Copyright (C) 2003, 2004 Marc 'HE' Brockschmidt <he@debian.org>
 
 =item Copyright (C) 2005-2007 Gunnar Wolf <gwolf@debian.org>
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2008 Gregor Herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2010 Gregor Herrmann <gregoa@debian.org>
 
-=item Copyright (C) 2007-2009 Damyan Ivanov <dmn@debian.org>
+=item Copyright (C) 2007-2010 Damyan Ivanov <dmn@debian.org>
+
+=item Copyright (C) 2008, Roberto C. Sanchez <roberto@connexer.com>
+
+=item Copyright (C) 2009-2010, Salvatore Bonaccorso <salvatore.bonaccorso@gmail.com>
 
 =back
 
